"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataApiResponseFormatter = void 0;
const tslib_1 = require("tslib");
const moment_1 = tslib_1.__importDefault(require("moment"));
const entities_1 = require("../entities");
class DataApiResponseFormatter {
    static formatResponse(responsePath, response) {
        for (const path of responsePath) {
            if (response) {
                response = response[path];
            }
        }
        return response;
    }
    static buildValueResponse(queryType, response) {
        switch (queryType) {
            case entities_1.DataApiQueryType.FIRST_OR_LAST:
                return DataApiResponseFormatter.buildFirstOrLastResponse(response);
            case entities_1.DataApiQueryType.LATEST_QUOTE:
                return DataApiResponseFormatter.buildLatestQuoteResponse(response);
        }
        return undefined;
    }
    static buildFirstOrLastResponse(response) {
        var _a, _b;
        if (response === undefined) {
            return undefined;
        }
        if (response.length === 0) {
            return undefined;
        }
        const first = (_a = response[0].first) === null || _a === void 0 ? void 0 : _a.toString();
        const last = (_b = response[0].last) === null || _b === void 0 ? void 0 : _b.toString();
        return {
            value: last !== null && last !== void 0 ? last : first,
            timestamp: (0, moment_1.default)(response[0].time).unix(),
        };
    }
    static buildLatestQuoteResponse(response) {
        var _a, _b, _c;
        if (response === undefined) {
            return undefined;
        }
        const price = response.price;
        const change24h = response.change_24h;
        const circulatingSupply = response.circulating_supply;
        const marketCap = response.market_cap;
        const volume24h = response.volume_24h;
        return {
            value: (_c = (_b = (_a = price !== null && price !== void 0 ? price : change24h) !== null && _a !== void 0 ? _a : circulatingSupply) !== null && _b !== void 0 ? _b : marketCap) !== null && _c !== void 0 ? _c : volume24h,
            timestamp: (0, moment_1.default)(response.timestamp).unix(),
        };
    }
    static buildAggregateResponse(response) {
        if (response === undefined) {
            return undefined;
        }
        if (response.length === 0) {
            return undefined;
        }
        return {
            first: response[0].first,
            last: response[0].last,
            min: response[0].min,
            max: response[0].max,
            count: response[0].count,
            sum: response[0].sum,
            avg: response[0].avg,
        };
    }
    static buildHistoricalResponse(response) {
        if (response === undefined) {
            return [];
        }
        return response.map((res) => ({
            first: res.first,
            last: res.last,
            min: res.min,
            max: res.max,
            count: res.count,
            sum: res.sum,
            avg: res.avg,
            timestamp: (0, moment_1.default)(res.time).unix(),
        }));
    }
    static buildMostUsedResponse(response) {
        if (response === undefined) {
            return [];
        }
        return response.map((res) => ({
            rank: res.rank,
            key: res.key,
            value: res.value,
        }));
    }
}
exports.DataApiResponseFormatter = DataApiResponseFormatter;
//# sourceMappingURL=response.formatter.js.map